==> Freya_alerce-0.1.4.8.8.tar.gz: configure.py <==

"""
configure.py is the most important file in Freya, this file is called for 
Freya’s core and FreyaAPI’s resources, is the only file you need to modify 
in principle. You need to complete the following methods. When using Freya’s 
method getData, you use this class for calls and depent what method call you 
need use ra and dec or hms, so that's why kwargs is used.

Need to complete the methods so that they return the indicated.
"""

from Freya_alerce.catalogs.core.abstract_catalog import BaseCatalog
from Freya_alerce.catalogs.NAME import ConnectNAME
from Freya_alerce.core.utils import Utils

class ConfigureNAME(BaseCatalog):
    """
    Parameters:
    ------------
    ra : (float) Right ascension
    dec :  (float) Declination
    hms : (string) HH:MM:SS
    radius: (float) Search radius
    nearest : (bool) selected the object most close to point
    """
    def __init__(self,*args,**kwagrs):
        self.ra = kwagrs.get('ra')
        self.dec = kwagrs.get('dec')
        self.hms = kwagrs.get('hms')
        self.radius = kwagrs.get('radius')
        self.nearest = kwagrs.get('nearest')

    def get_lc_deg(self):
        """
        Get all ligth curves data or the most close object, inside degree area from NAME catalog.
        Return
        -------
        Return numpy array 2d with rows represent the objects and columns : ['obj','ra','dec','mjd','mg','filter'].
            obj : double
                Id of object in catalog
            ra : double
                Right ascension
            dec : double
                Declination
            mjd : double
                Julian day
            mg : double
                Magnitud
            filter : str
                Band 
        """
        data_return = ""
        return data_return

    def get_lc_hms(self):
        """
        Get all ligth curves data or the most close object, inside hh:mm:ss area from NAME catalog.
        Return
        -------
        Return numpy array 2d with rows represent the objects and columns : ['obj','ra','dec','mjd','mg','filter'].
            obj : double
                Id of object in catalog
            ra : double
                Right ascension
            dec : double
                Declination
            mjd : double
                Julian day
            mg : double
                Magnitud
            filter : str
                Band 
        """
        ra_,dec_ = Utils().hms_to_deg(self.hms)
        data_return = ""
        return data_return

==> Freya_alerce-0.2.1.tar.gz: configure.py <==

"""
configure.py is the most important file in Freya, this file is called for 
Freya’s core and FreyaAPI’s resources, is the only file you need to modify 
in principle. You need to complete the following methods. When using Freya’s 
method getData, you use this class for calls and depent what method call you 
need use ra and dec or hms, so that's why kwargs is used.

Need to complete the method so that they return the indicated, if don't have a column replace with nan .
"""

from Freya_alerce.catalogs.core.abstract_catalog import BaseCatalog
from Freya_alerce.catalogs.NAME import ConnectNAME
from Freya_alerce.core.utils import Utils

class ConfigureNAME(BaseCatalog):
    """
    Parameters:
    ------------
    ra : (float) Right ascension
    dec :  (float) Declination
    radius: (float) Search radius
    nearest : (bool) selected the object most close to point
    """
    def __init__(self,*args,**kwagrs):
        self.ra = kwagrs.get('ra')
        self.dec = kwagrs.get('dec')
        self.radius = kwagrs.get('radius')
        self.nearest = kwagrs.get('nearest')

    def get_lc(self):
        """
        Get all ligth curves data or the most close object, inside degree area from NAME catalog.
        Return
        -------
        Return numpy array 2d with rows represent the objects and columns : ['obj','ra','dec','mjd','mg','filter'].
            obj : double
                Id of object in catalog
            ra : double
                Right ascension
            dec : double
                Declination
            mjd : double
                Julian day
            mg : double
                Magnitud
            filter : str
                Band 
        """
        data_return = ""
        return data_return
